/**
 * apeman template of dot files.
 * @memberof module:apeman-tmpl-dot/lib
 * @function load
 * @param {object} params - Template params.
 * @param {string} type - Template type.
 * @param {string} [mode='644'] - File permission.
 * @param {boolean} [force=false] - Override or not.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    assert = require('assert'),
    _tmpl = require('./_tmpl');

/** @lends load */
function load(params, mode, force) {
    let args = argx(arguments);
    params = args.shift('object');

    assert(params.type, "params.type is required.");

    return {
        force: !!force,
        mode: mode || '644',
        get tmpl() {
            let tmpl = _tmpl(params.type);
            assert.ok(tmpl, "Type not found: " + params.type);
            return tmpl;
        },
        data: {
            year: params.year || new Date().getFullYear(),
            params: params,
            generator: 'apeman-tmpl',
            today: new Date().toLocaleDateString(),
            pkg: require('../package.json')
        }
    }
}

module.exports = load;
